#Archiving New Naturals

##towards a context-aware global material commons: what's in *your* local archive?

![](../images/presentation-4.jpg)*Material samples, Loes Bogers, 2020*

**The goal of this project was to explore and develop simple methods for open archiving of socalled "new naturals"\*. The outcomes are developed to work toward a collaborative, global - but context-aware - material archive....**

- that is not only ecologically, but also historically, culturally, geographically aware;
- that can extend material activism beyond bioplastics;
- that promotes an open-source attitude to the development of design materials, and credits the work done by others before you;
- that acknowledges all those practical questions: from buying the right kind of ingredient, all the way to tips and tricks for that challenging phase of controlled drying and curing materials to its "final" form;
- that is explained in layman's terms, demystifying ingredients and processes without oversimplifying them;
- imaging collaborative open archiving that can facilitate critique, contestations, suggestions, updates and reviews from peers;
- offering a package that allows novices to learn, and educators to get started in a systematic way...
- ... and encourages experienced material designers and "alchemists" to continue asking the hard critical questions regarding sustainability and share those considerations with each recipe or ingredient.

\* *note: "new" or "other" naturals is not a thing (yet). But the word is sometimes used in material archives as container category for materials that don't fit the traditional material families of wood, hide, metal, glass, plastics, stone, etcetera. New or other naturals is a left-over tag to indicate composite or otherwise hybrid materials made from renewable natural resources such as food waste, plant fibres etcetera.* 

##Outcomes

A curated selection from best practices found in research labs, material archives and design studios from all over the world. The information itself was already widely known, this project is an effort to ask new questions, and think up new structures for organising and building on this knowledge in open, collaborative ways, not over-simplifying nor mystifying the information and skills needed. It is also an exercise in learning globally, but practicing *locally*, using resources locally abundant in your location (which for me, was the Netherlands).

- [**development brief**](https://docs.google.com/presentation/d/1YRHikbOnj0WLbVhc2BELcTUBk30rFFGOpYzF1ra7Jp4/edit?usp=sharing) for a context-aware, collaborative materials database that enables peer feedback, ratings and constructive criticism. 
- [**25 foundational recipes**](../recipes) to start your own sample archive (based on ingredients that are largely locally abundant in the Netherlands). What will be *your* list of 25 recipes using resources abundant in your location?
- [**list of tools**](../tools) needed to start your own material samples archive
- [**video tutorial**](https://class.textile-academy.org/2020/loes.bogers/projects/templates/tactilityvideo/) for capturing tactility of material samples
- [**template for new recipes**](https://class.textile-academy.org/2020/loes.bogers/projects/templates/new_recipe/), to help you capture the entire proces, ask the hard contextual questions and document relevant considerations when contributing new recipes to the database.
- [**template to add new ingredients**](https://class.textile-academy.org/2020/loes.bogers/projects/templates/new_ingredient/), helping you ask the hard questions and document relevant considerations when contributing new recipes to the database.
- [**templates for labels**](https://class.textile-academy.org/2020/loes.bogers/projects/templates/labels/) to create your own physical archive with material samples (building on the work of Maria Viftrup for TextileLab Waag).
- [**a glossary of terms**](https://class.textile-academy.org/2020/loes.bogers/projects/glossary/), explaining the key terms used here (in progress)
- [**an educators' note**](https://class.textile-academy.org/2020/loes.bogers/projects/note_for_educators/) with some suggestions for how this archive might be incorporated into classes oriented to designing/material research/critical making/design & crafts history/machine building classes.

This project is indebted to the knowledge collected and created in and around the Fabricademy network, and builds upon the (physical) Material Archive at Textile Lab Waag that was realised by Cecilia Raspanti, Maria Viftrup and others in 2016-2017.

###Future development

- realising the online database further with a designer and developer
- develop, document and add methods for simple material testing
- add section for open-source DIY tools for fabrication
- further testing of the formats as tools for learning in higher education and fabricademy, gathering peer feedback from peers
 
##State of the art 

We are in a moment where more and more designers are starting to recognize the importance of materials and unlearning our wasteful and toxic addictions to plastic and other common design materials. This is a wildly interesting field that can be approached from many perspectives. This project contributes less to the *material engineering* side of materials research, but is more focused on the DIY, open-source approaches to it that can be useful for designers and makers to be used in critical material imaginaries.

Below is a discussion of a small selection from the current state of the art. This project is hugely indebted to each of them and the amazing work the people behind it have done. The critiques here come from a commitment to push the work further and extend the work others did before us. If you feel like your work should be acknowledged here or in the recipes, please contact me at l[dot]bogers[at]hva[dot]nl.

###1. Classifying "new natural" materials

**Material District**

Commercial material archives are committed to showcasing new materials and rethinking ways of presenting material innovations (which can either be high-tech and innovative, or more innovative in the sense of sustainability). [Material District](https://materialdistrict.com/) is a match-making platform for organisations involved in R&D of materials, and design professionals. This organization hosts an annual materials fair in the Netherlands, and hosts an online archive, where new materials are logged together with some technical material properties, and information about manufacturers. New materials can be showcased at a cost of €100 per year. 

Their role in matchmaking R&D with designers and industry is important and pivotal in promoting the uptake of new materials (Damadei, 2019). 

But the classification systems continue to rely on traditional material families like wood, ceramics, and metals, and except for the container category of "other naturals". New and often hybrid materials require us to rethink such categories (Kula & Ternaux 2019: p. 337-338), but new models are still lacking. 

One avenue might be to explore and make explicit the tactile qualities of materials, alongside their technical properties. Material District does this in a summarized way (see image below) that gives an overview of the material that is accessible to novices. But their clients have to continue to rely on the big materials fair for get a "feel" for the different materials on offer. 

![](../images/materialdistrict.jpg)*Properties listed for each material on the Material District Archive, screenshot of their website, 2020*

**MATto Design**

Besides the inspiration taken from Material District, the archive put forward here incorporates the sensory descriptors and categories proposed by Beatrize Lerma in her article "Materials ecoefficiency and perception. Proceedings" (2010: pp. 1-8). Discussing an existing reference tool called SensoTact, she describes a sensory vocabular to describe materials (e.g. stickiness, rough/smooth, hot/cold) in addition to parameters to evaluate socalled *material eco-compatibility*. [MATto](http://www.matto.design/en/home/), the materials library and consultancy service at the Politecnico di Torino has adopted this approach (but is not open to the public). To describe relative sustainability, Lerma suggests to discuss parameters such as toxicity, energy involved in production, shelf life, and distance to source. 

**Physical forms vs. material families**

In parallel to the traditional materials families (wood, metals, etc) the MATto materials library *also* organizes materials more in line with fabrication methods and physical forms that are recognizable and useful to designers. Users can also navigate the archive by browsing collections put together based on their physical form: e.g. slabs, tubes & pipes, foam and expanded materials, textiles, grilles & nets, surface treatments, gels and pastes, grains/flakes & powders, and so on. This is an interesting approach that allows designers to consider different alternatives for a part of a product. For example someone designing a speaker might browse the "grilles and nets" sections and find composites made with yarns or other fibres she would never find browsing polymers. The physical forms are another method we explore in this project, but in a more simplified manner. User interviews I did during the project showed that these categories were the most meaninful that could capture all: surfaces & surface treatments, solids, powders/grains, liquids/gels, and strings/tubes.

![](../images/matto.jpg)*Phycisal forms and material families alongside one another, Screenshot from their website, 2020*

###2. Physical Material Archives

**Tactile experience of materials**
The ways of categorizing and describing material samples listed above are useful and easy to implement in text-based databases. But can only give a limited feel for the aesthetics and tactility of a material. 

The physical [Material Archive](https://viftrup.com/textilelab) developed at Textile Lab Waag, by Cecilia Raspanti and designed by Maria Viftrup and others from 2016 onwards continues to be one of the most effective ways of offering alternatives to designers. Not only because it offers visitors to meet the materials, and touch, smell and manipulate them, but it also allows them to take them home. Not in the sense that they can take the materials home, but because the recipe and technique to recreate the material is documented on the back of the label attached to the sample. Of course the memory of the tactile experience fades in a way that photographs and words cannot recover. What might be other ways to document tactility?

<iframe src="https://player.vimeo.com/video/243628535" width="640" height="360" frameborder="0" allow="autoplay; fullscreen" allowfullscreen></iframe>
<p><a href="https://vimeo.com/243628535">Material Archive promo - by Maria Viftrup</a> from <a href="https://vimeo.com/waagmakers">Makers of Waag</a> on <a href="https://vimeo.com">Vimeo</a>.</p>

Their archive is divided into "raw" and "made" materials and a loosely organised but effective tagging system to indicate what kind of material a given sample is. The downside here, is that the Material Archive at Textile Lab Waag does not have any kind of online accessible version of the archive, and updating recipes when new insights are formed can be an issue, as a recipe will always be tied to that particular tangible sample. This project hopes to contribute to their efforts by suggesting ways to bring this amazing archive online. 

![](../images/institutemaking.jpg)*The materials library at the Institute of Making, UCL London, Loes Bogers, 2020*

The [Institute of Making](https://www.instituteofmaking.org.uk/) at UCL London has a materials library with another interesting approach that lets go of classification systems altogether. Their exhibition space continuously changes to offer fresh perspectives on materials, and can vary from chronological ordering, or it can be an exhibition around controversial materials. The story is the organizing factor here, and always depends on the availability of staff and slots to visit the archive. They offer a valuable (design-)historical perspective on materials, but do not organize or offer any practical information for manufacturing and manipulating them. 

It is difficult to separate the material from the form however. Most of the "materials" in this library are already *applied*. They have already taken shape as a functional object, which could make it challenging to disentangle the form and possible functions/shapes/forms. Also, this library contains a lot of materials that would be hard to impossible to recreate without specialist tools and knowledge. 


###3. Renewable and DIY: Material Activism

We should also take note of the work other critical designers have done before in the realm of materials research & development. Many designers have develped their own versions of materials, and great applications for them in their design practice. And there are dozens of beautiful big books to showcase them. Although they may create *awareness* and inspiration when it comes to these approaches to design and materials, most often, the exact recipe or process is not disclosed. Even more problematic is that it is very common for a designer to use a crafts or heritage technique and presents it as though it has been their discovery, paying no credit to the cultural history such practices emerged from. Many of the techniques hailed as sustainable material innovatinos are in fact rediscovered old techniques. 

**Open-source material activism**

Miriam Ribul's framing of DIY bioplastics as material activism (2013) that should be open-source is pivotal here. With this open access publication Ribul shares 4 basic recipes for bioplastics that can be created at home with ingredients bought at a super market. She argues for collaborative approaches to radical imaginaries when it comes to the issue of our collective plastic addiction. The focus on *only renewable* ingredient is unique to the approaches listed so far (which may come as a surprise). Such a strict approach, with *only* DIY recipes, and simple, renewable ingredients (which we also see in Materiom, below) is essential when it comes to rethinking materials. We cannot yield to the temptations of high-tech materials alone, but must continue to push for *sustainable* approaches to high-tech only. 

The DIY recipe book is a popular format which we also see in Clara Davis - [*The Secrets of Bioplastic*](https://issuu.com/nat_arc/docs/the_secrets_of_bioplastic_) (2017), Margaret Dunne's [*The Bioplastics Cookbook: A Catalogue of Bioplastics Recipes*](https://issuu.com/nat_arc/docs/bioplastic_cook_book_3) (2018). It demystifies the processes of material design, keeping the form very rudimentary, allows it to stay open to interpretation and further development. Although it opens up a wealth of information with this format, they remain static. How can we make this kind of development ongoing? Another downside to these publications is that they are unlikely to go very in depth in terms of tooling options, drying time, etcetera because there's an incentive to keep recipes short and fit them on a page or a spread. On the other hand that is exactly what makes them accessible.  

Lastly, there seems to be a danger with such recipe books because they often take a narrow focus for the sake of clarity and coherence. As a historical parrallel: the "natural textile dyeing" books from the 1970s would celebrate and appreciate nature's splendor, while including heavy metals and toxic compounds as mordants in their recipes. In a similar way, we see that some recipe books eagerly consider renewable alternative to petrol-based plastics, but don't find it worth mentioning that animal-based products such as gelatine might be an issue as well. 

###4. Collaborative databases 
 
[Materiom](https://materiom.org/) is a great initiative that takes the open-source, DIY, renewable-only approach, and makes efforts to collect and present recipes in a beautifully designed environment that is accessible online. Users can add their own recipes so the archive can continue to grow. Beautiful photography makes these materials very appealing and desirable as a design material as well. 

In the same way that family recipes are contested, and cooks claim to have the "ultimate" recipe to a ragu bolognese, material recipes will be contested. We've seen this in the myriad ways people craft and form materials in the context of this Fabricademy course. Great value could be added if collaborative databases also facilitated debate, contestation and forking of certain recipes. With peer reviews and rating we might be able start to see patterns as to which technique work best for whom. Where are they in the world? What are their environmental conditions and which type of which ingredient are they using? 

A platform like Materiom might also benefit from acknowledging more explicitly where these crafts practices are coming from, and taking a more critical stance as to when something is *more sustainable*. As no material is perfect or without issues, we need more concrete handles for assessing the ethics of using certain materials in particular context or applications. Expanding the amount and type of entry fields required when submitting a new recipe could potentially help the community of "material nerds" deepen their understanding of what they are working with, so material activism extends beyond the ecological, into the social, cultural, political, and technical. 


## Archiving New Naturals: A Manifesto

*As a starting point for the project, I wrote this manifesto for the obsessively curious, the critical makers, the material nerds. Now let's keep going. By Loes Bogers, 2 April 2020*

- **we need *ongoing* material activism**, especially in the face of smart and advanced materials increasing popularity. What could be methods to continue to demystify material craftsmanship as materials research evolves and becomes highly technical and less accessible due to increasing complexity as well as patenting intellectual property?
- **if plactics are not the only issue, then bioplastics are not the only solution**, dyeing and chemical treatments and finishes are equally if hazardous for the environment and workers. Biodegradable, or even biocompostable plastics don't solve all our problems
- **designers and makers need to get comfortable drawing from different fields of knowledge** and their methods like empirical approaches and systematic ways of experimenting and documenting, such as in fields of biology, chemistry and other "hard" sciences.
- but we need to be equally **aware of history, cultural heritage and the politics of design materials** in terms of their cultural history, as well as their socio-economic and ecological implications. 
- **we need open-source material knowledge**: if resources are part of the commons, then so are material kowledge and craftsmanship, but we need to contiue to build it up and keep it alive. 
- **make materials from scratch**: as this will bring the entire ecology of material knowledge, production, distribution and legislation into view and open to questioning;
- **cultivate material craftsmanship** and understand the importance time and controlled environments effect on a material's growth/curing/drying. But equally, learn to work *with* any material (rather than expecting it to bend to your will). 
- look for and learn to appreciate **locally abundant resources** and their potential, and start to see them appear in very unlikely places;
- **spend time with materials and resources**, attention and dedication to the cooking/curing/drying or growth process will allow you to start seeing alternative uses, options, applications.
- **learn from practices from all over the world** to strengthen your own locally centered practice (not yielding to the temptation of turning that wealth of knowledge into a candy shop);
- **ask questions to stay with the trouble** of socalled sustainable materials, rather than setting out to find silver bullet solutions.
- **document and share** your process, research and outcomes using formats to describe their sensory and technical properties, and give an impression of their tactile, and auditory qualities. 


##References

- **Materials ecoefficiency and perception** by Beatrice Lerma, in Proceedings: CESB 2010 Prague - Central Europe towards Sustainable Building 'From Theory to Practice', 2010: pp. 1-8.
- **Materiology: The Creative Industry’s Guide to Materials and Technologies** by Daniël Kula & Elodie Ternaux, Basel: Birkhäuser, 2014.
- **Institute of Making - Fourth Year Report 2016-2017**, by the Institute of Making, UCL London, 2017: [link](https://www.instituteofmaking.org.uk/about)
- **Recipes for Material Activism** by Miriam Ribul, 2014, via issuu [link](https://issuu.com/miriamribul/docs/miriam_ribul_recipes_for_material_a)
- **Research Book Bioplastics** by Juliette Pepin, 2014, via issuu [link](https://issuu.com/juliettepepin/docs/bookletbioplastic)
- **The Secrets of Bioplastic** by Clara Davis (Fabtex, IAAC, Fab Lab Barcelona), 2017, [link](https://issuu.com/nat_arc/docs/the_secrets_of_bioplastic_).
- **The Bioplastics Cookbook: A Catalogue of Bioplastics Recipes** by Margaret Dunne for Fabtextiles, 2018, [link](https://issuu.com/nat_arc/docs/bioplastic_cook_book_3)
- **DAMADEI: Design & Advanced Materials as a Driver of European Innovation**, by Damadei project committee, funded by the European Commission, 2013.  



